Examples overview
=================

..  info::

    All examples are located under the :si-icon:`octicons/mark-github-16`
    :github-tree:`examples/` subdirectory inside the repository.

..  important::

    Some examples require additional third-party packages. Install them with:

    ..  include:: /includes/install-examples.txt

Unless specified otherwise in the example's ``README.md`` (or in the example's
documentation here) you can run the example like a script:

..  shell::
    :cwd: ..
    :rel: ..
    :user: josephine
    :host: laptop

    python -m examples.hello_world

Examples can be explored in any order, but - in general - they progress from
simple subjects to more complex ones in the order they appear in the
documentation here.
